@@ -12,19 +12,31 @@
 #include <SDL.h>
 
 
-double WaitRatio = 1.0;
-SDL_mutex* Mutex = NULL;
+static double WaitRatio = 1.0;
+static SDL_mutex* Mutex = NULL;
 
+/*!
+  \brief SdlInit ̏NX
+*/
 class SdlInitClass : private SdlInit {
 };
 
 static void mutexInitialize(void) {
   static SdlInitClass sdl_init;
   static SDL_mutex* obj = SDL_CreateMutex();
-  Mutex = obj;
+  if (Mutex == NULL) {
+    Mutex = obj;
+  }
 }
 
 
+/*!
+  \brief ҋ@֐
+
+  w莞Ԃҋ@B
+
+  \param msec [i] ҋ@ [msec]
+*/
 void delay(unsigned long msec) {
   mutexInitialize();
 
@@ -37,6 +49,13 @@ void delay(unsigned long msec) {
 }
 
 
+/*!
+  \brief Ԃ̐is䗦ݒ
+
+  j^@\ɂāAȂǂ̂ɗpB
+
+  \param ratio [i] Ԃ̂݋B2.0 ƂQ{
+*/
 void setDelayRatio(double ratio) {
   mutexInitialize();
 
