@@ -17,6 +17,9 @@
 class SocketSet;
 
 
+/*!
+  \brief Mf[^̋L^NX
+*/
 class ConnectionLogger : public ConnectionInterface {
   ConnectionLogger(void);
   ConnectionLogger(const ConnectionLogger& rhs);
@@ -26,7 +29,7 @@ class ConnectionLogger : public ConnectionInterface {
   const std::auto_ptr<pImpl> pimpl;
 
 public:
-  ConnectionLogger(ConnectionInterface* com);
+  ConnectionLogger(ConnectionInterface* con);
   ~ConnectionLogger(void);
 
   const char* what(void);
@@ -36,10 +39,15 @@ public:
   int changeBaudrate(long baudrate);
   int send(const char* data, int size);
   int recv(char* data, int size, int timeout);
-  int size(void);
+  int size(int timeout = 0);
   void clear(void);
   void skip(int timeout);
 
+  /*!
+    \brief Ȍo̓t@Cݒ
+
+    \param logfileName [i] Ȍo̓t@C
+  */
   void setLogfileName(const char* logfileName);
 };
 
