@@ -24,7 +24,7 @@ class NetInit {
   const std::auto_ptr<pImpl> pimpl;
 
 protected:
-  explicit NetInit(void);
+  NetInit(void);
   ~NetInit(void);
 };
 
