@@ -1,6 +1,6 @@
 /*!
   \file
-  \brief \PbgZbgǗ
+  \brief ʐM\PbgǗ
 
   \author Satofumi KAMIMURA
 
