@@ -3,7 +3,7 @@
 
 /*!
   \file
-  \brief \PbgZbgǗ
+  \brief ʐM\PbgǗ
 
   \author Satofumi KAMIMURA
 
@@ -24,7 +24,7 @@ class TcpipCtrl;
 
 
 /*!
-  \brief \PbgZbgǗ
+  \brief ʐM\PbgǗ
 */
 class SocketSet {
   SocketSet(const SocketSet& rhs);
@@ -34,11 +34,38 @@ class SocketSet {
   const std::auto_ptr<pImpl> pimpl;
 
 public:
+  /*!
+    \brief RXgN^
+
+    \param size [i] Ԃł̃\Pbge
+  */
   explicit SocketSet(size_t size = 1);
   ~SocketSet(void);
 
+  /*!
+    \brief \Pbg̓o^
+
+    \param socket [i] o^\Pbg
+
+    \retval true o^ɐ
+    \retval false o^Ɏs
+  */
   bool add(TCPsocket socket);
+
+  /*!
+    \brief \Pbg̍폜
+
+    \param socket [i] 폜\Pbg
+  */
   void del(TCPsocket socket);
+
+  /*!
+    \brief Mf[^邩̊mF
+
+    \param timeout [i] ^CAEg [msec]
+
+    \return Mf[^̂\Pbg
+  */
   size_t check(int timeout);
 };
 
