@@ -60,7 +60,7 @@ public:
   int changeBaudrate(long baudrate);
   int send(const char* data, int size);
   int recv(char* data, int size, int timeout);
-  int size(void);
+  int size(int timeout = 0);
   void clear(void);
   void skip(int timeout);
 
