@@ -11,10 +11,12 @@
 */
 
 #include "JoystickInterface.h"
-#include <SDL.h>
 #include <memory>
 
 
+/*!
+  \brief USB WCXeBbN͂̎擾NX
+*/
 class UsbJoystick : public JoystickInterface {
   UsbJoystick(const UsbJoystick& rhs);
   UsbJoystick& operator = (const UsbJoystick& rhs);
