@@ -17,6 +17,9 @@ class ConnectionInterface;
 class SensorParameter;
 
 
+/*!
+  \brief SCIP2.0 
+*/
 class ScipHandler {
   ScipHandler(const ScipHandler& rhs);
   ScipHandler& operator = (const ScipHandler& rhs);
@@ -32,21 +35,24 @@ public:
 
   void setConnection(ConnectionInterface* con);
   void disconnect(void);
-  bool isConnected(void);
+  bool isConnected(void) const;
   bool adjustBaudrate(long baudrate);
   bool setBaudrate(long baudrate);
   bool getVersionInfo(std::vector<std::string>& lines);
   bool loadSensorParameter(SensorParameter* parameter);
+  void setSensorParameter(const SensorParameter* parameter);
   void setCaptureTimes(size_t times);
-  void sendCaptureMessage(void);
-  int recvCaptureData(long* data, size_t max_size,
-		      size_t& timestamp, int timeout);
+  void sendCaptureMessage(char cmd = 'M');
+  int recvCaptureData(long* data, size_t max_size, size_t& timestamp);
   int capture(long data[], size_t max_size, size_t& timestamp);
+  void stopCapture(void);
   void setFrameSkipFrames(size_t skip_frames);
   void setDataGroups(size_t groups);
   void setCaptureRange(int first_index, int last_index);
-  long getMinDistance(void);
-  int getMaxDataLength(void);
+  long getMinDistance(void) const;
+  long getMaxDistance(void) const;
+  int getMaxDataLength(void) const;
+  int getScanRpm(void);
   void setLaserOutput(bool on);
   double index2rad(const int index);
   int rad2index(const double radian);
